@@ -104,7 +104,7 @@ class MarketAnalyzer:
         # Update parameters of parser_metrics
         for m in self.parser_metrics.keys():
             if 'period' in self.parser_metrics[m]['p'].keys():
-                self.parser_metrics[m]['p']['period'] = self.n_day_per_year
+                self.parser_metrics[m]['p']['period'] = 365#self.n_day_per_year
 
             # if 'lags' in self.parser_metrics[m]['p'].keys():
             #    self.parser_metrics[m]['p']['lags'] = min(63, max(1, t - 3))
@@ -270,9 +270,27 @@ class MarketAnalyzer:
 
         if drop_duplicate:
             print('dropping duplicate')
-            #_, indices = np.unique(results, axis=1, return_index=True)
-            kpis_df = kpis_df.T.drop_duplicates().T
+            def suppress_dup_cols(dataf):
+                filtered_dataf = dataf.copy()
+                all_columns = list(dataf.columns)
 
+                for col_one in all_columns:
+                    identical_mapping = set()
+                    if col_one in filtered_dataf.columns:
+                        for col_two in filtered_dataf.columns:
+                            s1 = filtered_dataf[col_one]
+                            s2 = filtered_dataf[col_two]
+                            if not col_one == col_two:
+                                if ((s1 == s2).all()):
+                                    identical_mapping.add(col_two)
+                        print('dropping ' + str(identical_mapping))
+                    filtered_dataf = filtered_dataf.drop(columns=identical_mapping)
+                return filtered_dataf
+
+            filtered_kpis_df = suppress_dup_cols(kpis_df.T.copy())
+
+            print('duplicated dropped')
+            kpis_df = filtered_kpis_df.T.copy()
         if only_one_per_type :
             print('keeping only the best per filter type')
             kpis_df = kpis_df.T
