@@ -40,7 +40,9 @@ def request_minute_data_paquet(url, me_ts, ssj):
     return dataframe
 
 def request_hour_data_paquet(url, me_ts, ssj):
-    r = requests.get(url.format(ssj, me_ts))
+    hours_url_request=url.format(ssj, me_ts)
+#    print(hours_url_request)
+    r = requests.get(hours_url_request)
     dataframe = None
     try:
         dataframe = pd.DataFrame(json.loads(r.text)['Data'])
@@ -374,6 +376,7 @@ def fetch_local_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_r
 def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_pkl_filename_suffix='_hourly_returns.pkl',refetch_all=True, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, ssj_against='USDT', exchange = 'binance'):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
     pickle_saving_path = local_root_directory + ssj + '_' + dates_stub + hourly_return_pkl_filename_suffix
+
     if refetch_all:
         year = datetime.datetime.now().year
         month = datetime.datetime.now().month
@@ -402,7 +405,6 @@ def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_
         print('Loading data')
         #hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&e=' + exchange + '&toTs={}&limit=2000'
         hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&toTs={}&limit=2000'
-
         dataframe = None
         for me_timestamp in [ts18, ts17, ts16, ts15, ts14, ts13, ts12, ts11, ts10, ts9, ts8, ts7, ts6, ts5, ts4, ts3, ts2, ts1, ts]:
             print('waiting')
