@@ -62,14 +62,16 @@ def f_drawdown(assets, X, previous_w, cost_parameters, w):
 
 class AbstractAssembler(ABC):
     def __init__(self, starting_date=None, running_date = None, drop_token=None, dropbox_backup = True, features_pkl_file_suffix='_features.pkl', macro_features_directory='features_macro', returns_pkl_file_suffix='_returns.pkl', local_root_directory='../data/', user='napoleon',
-                 supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', transaction_costs = None):
+                 supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', transaction_costs = None, crypto_ticker = None):
         super().__init__()
 
         self.features_pkl_file_suffix = features_pkl_file_suffix
         self.returns_pkl_file_suffix = returns_pkl_file_suffix
 
-        self.features_pkl_file_name = running_date.strftime('%d_%b_%Y')+features_pkl_file_suffix
-        self.returns_pkl_file_name = running_date.strftime('%d_%b_%Y')+returns_pkl_file_suffix
+        if features_pkl_file_suffix is not None:
+            self.features_pkl_file_name = running_date.strftime('%d_%b_%Y')+features_pkl_file_suffix
+        else :
+            self.features_pkl_file_name = None
 
         self.macro_features_directory=macro_features_directory
         self.local_root_directory = local_root_directory
@@ -82,6 +84,12 @@ class AbstractAssembler(ABC):
         self.starting_date = starting_date
         self.transaction_costs = transaction_costs
 
+        self.crypto_ticker = crypto_ticker
+        if self.crypto_ticker is not None:
+            self.returns_pkl_file_name =  self.crypto_ticker + '_' +self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y') + self.returns_pkl_file_suffix
+        else :
+            self.returns_pkl_file_name = self.running_date.strftime('%d_%b_%Y') + self.returns_pkl_file_suffix
+
     @abstractmethod
     def computeUtility(self, s):
         pass
@@ -97,6 +105,8 @@ class UtilitySuperviser(AbstractAssembler):
         strats = [col for col in list(df.columns) if col != 'Date']
 
         print('size return '+str(df.shape))
+
+
         advanced_features = self.dbx.local_overwrite_and_load_pickle( folder='', subfolder=self.macro_features_directory, returns_pkl_file_name=self.features_pkl_file_name, local_root_directory = self.local_root_directory)
         features_names = [col for col in list(advanced_features.columns) if col!='Date']
         advanced_features['Date'] = pd.to_datetime(advanced_features['Date'])
@@ -121,7 +131,7 @@ class UtilitySuperviser(AbstractAssembler):
 
         df_bis = df.copy()
 
-        print('merging')
+        print('merging with advanced features')
         df_bis = pd.merge(df_bis, advanced_features, how='left', on=['Date'])
 
         print('merging done')
@@ -136,9 +146,6 @@ class UtilitySuperviser(AbstractAssembler):
         print('Final returns size after merge with features')
         print(df_ret.shape)
 
-
-        prices = df_bis[strats].values
-
         for col in strats:
             print(col + str(len(df_bis.columns)))
             df_ret[col] = df_bis[col].pct_change().fillna(0.)
@@ -149,9 +156,6 @@ class UtilitySuperviser(AbstractAssembler):
         ret_df = df_ret[strats]
         ret = ret_df.values
 
-        feat = df_ret[features_names].values
-        dates = df_ret.index
-
 
         T = df.index.size
         N = df.columns.size
