@@ -122,7 +122,7 @@ def perfligne(df, perf):
     # Année n
     year = fin
     if finm == 1:
-        S[A.shape[0] - 1, 0] = y[perf].values[-1] / end_month.loc[datetime.datetime(year - 1, 12, 31)] - 1
+        S[A.shape[0] - 1, 0] = df[perf].values[-1] / end_month.loc[datetime.datetime(year - 1, 12, 31)] - 1
     else:
         for i in range(finm):
             S[A.shape[0] - 1, i] = end_month_return[
@@ -140,7 +140,8 @@ def display_perf_table(df, perf, vmin1=None, vmax1=None, vmin2=None, vmax2=None)
     """
     df.index = pd.to_datetime(df.index)
     init = df.index[1]
-    A = np.arange(init.year, datetime.datetime.today().year + 1, 1)
+    fin = df.index[-1]
+    A = np.arange(init.year, fin.year + 1, 1)
 
     dfmonth = pd.DataFrame(index=A,
                            columns=["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
