@@ -516,6 +516,10 @@ def sharpe(series, period=252, from_ret = False):
     return (np.float_power(np.cumprod(1+ret_vect)[-1], period/np.size(ret_vect))-1) /\
            (np.sqrt(period)*np.std(ret_vect, dtype=np.float64))
 
+def normalize(series, initial_price = 100.):
+    series = series.pct_change()
+    series = series.fillna(0.)
+    return initial_price * (1 + series).cumprod()
 
 def roll_sharpe(series, period=252, win=0, cap=True):
     rollingSharpe = lambda rets : sharpe(rets, period)
